==> client-java-api-7.0.0-sources.jar: io/kubernetes/client/openapi/models/V1WatchEventFluentImpl.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1WatchEventFluentImpl<A extends V1WatchEventFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1WatchEventFluent<A>{

    private RuntimeRawExtensionBuilder _object;
    private String type;

    public V1WatchEventFluentImpl(){
    }
    public V1WatchEventFluentImpl(V1WatchEvent instance){
            this.withObject(instance.getObject());

            this.withType(instance.getType());

    }

    
/**
 * This method has been deprecated, please use method buildObject instead.
 * @return The buildable object.
 */
@Deprecated public RuntimeRawExtension getObject(){
            return this._object!=null?this._object.build():null;
    }

    public RuntimeRawExtension buildObject(){
            return this._object!=null?this._object.build():null;
    }

    public A withObject(RuntimeRawExtension _object){
            _visitables.get("_object").remove(this._object);
            if (_object!=null){ this._object= new RuntimeRawExtensionBuilder(_object); _visitables.get("_object").add(this._object);} return (A) this;
    }

    public Boolean hasObject(){
            return this._object != null;
    }

    public V1WatchEventFluent.ObjectNested<A> withNewObject(){
            return new ObjectNestedImpl();
    }

    public V1WatchEventFluent.ObjectNested<A> withNewObjectLike(RuntimeRawExtension item){
            return new ObjectNestedImpl(item);
    }

    public V1WatchEventFluent.ObjectNested<A> editObject(){
            return withNewObjectLike(getObject());
    }

    public V1WatchEventFluent.ObjectNested<A> editOrNewObject(){
            return withNewObjectLike(getObject() != null ? getObject(): new RuntimeRawExtensionBuilder().build());
    }

    public V1WatchEventFluent.ObjectNested<A> editOrNewObjectLike(RuntimeRawExtension item){
            return withNewObjectLike(getObject() != null ? getObject(): item);
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public A withNewType(String arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuilder arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1){
            return (A)withType(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            V1WatchEventFluentImpl that = (V1WatchEventFluentImpl) o;
            if (_object != null ? !_object.equals(that._object) :that._object != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }


    public class ObjectNestedImpl<N> extends RuntimeRawExtensionFluentImpl<V1WatchEventFluent.ObjectNested<N>> implements V1WatchEventFluent.ObjectNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final RuntimeRawExtensionBuilder builder;
    
            ObjectNestedImpl(RuntimeRawExtension item){
                    this.builder = new RuntimeRawExtensionBuilder(this, item);
            }
            ObjectNestedImpl(){
                    this.builder = new RuntimeRawExtensionBuilder(this);
            }
    
    public N and(){
            return (N) V1WatchEventFluentImpl.this.withObject(builder.build());
    }
    public N endObject(){
            return and();
    }

}


}

==> client-java-api-9.0.2-sources.jar: io/kubernetes/client/openapi/models/V1WatchEventFluentImpl.java <==
package io.kubernetes.client.openapi.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1WatchEventFluentImpl<A extends V1WatchEventFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1WatchEventFluent<A>{

    private Object _object;
    private String type;

    public V1WatchEventFluentImpl(){
    }
    public V1WatchEventFluentImpl(V1WatchEvent instance){
            this.withObject(instance.getObject());

            this.withType(instance.getType());

    }

    public Object getObject(){
            return this._object;
    }

    public A withObject(Object _object){
            this._object=_object; return (A) this;
    }

    public Boolean hasObject(){
            return this._object != null;
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public A withNewType(String arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuilder arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1){
            return (A)withType(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            V1WatchEventFluentImpl that = (V1WatchEventFluentImpl) o;
            if (_object != null &&_object != this ? !_object.equals(that._object) :that._object != null &&_object != this ) return false;

            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }




}
